#include <Servo.h>   // Include Servo Library

Servo DirServo;      // Servo Name
unsigned char Mbuff[4];   // Declare the Motor Control Char array
const int IRPin = 0;
const int motor_reset = 2;
const int BtnPsh = 4;
int DangerZone = 470;    // Set how close to the object you want to get
    //My Readings 20cm=485,30cm=395,50cm=240,70cm=160,100cm=115,150cm=90
    
void setup()
{
  DirServo.attach(3);     // Attach the Servo to Pin 3
  DirServo.write(90);     // Point servo straight ahead
  delay(350);
  pinMode(BtnPsh, INPUT);
  pinMode(motor_reset, OUTPUT);
  Serial.begin(9600);
  
    Mbuff[0]=0x80;  // Assign the start byte to control the Pololu Low Voltage motor controller
    Mbuff[1]=0x00;  // Assign the Address of the Motor Controller
    Mbuff[2]=0x00;     // This is the Motor Number & Direction. ONLY ONE THAT CHANGES
    Mbuff[3]=0x45;  // Assign the Speed 0x00 (0) Stopped to 0x7F (179) Full Speed, 0x45 = 69 of a 179 total
  
 /* 
  //  Config the Motor Controller to have 2 motors, starting at Motor No. 0
  unsigned char Mbuff[3];
    Mbuff[1]=0x02;   // Config Command code
    Mbuff[2]=0x00;   // 2 motors, starting at No 0
    MWrite();
  // REMOVE ALL OTHER CODE AND ONLY RUN THIS, ONCE
   */
  
  digitalWrite(motor_reset, LOW);    // Reset the Motor Controller
  delay(100);
  digitalWrite(motor_reset, HIGH);
  delay(200);
}

void loop()
{
   if (digitalRead(BtnPsh) == HIGH)  // Waits for Button push to start moving
   {
   MForward();
   }
    if (analogRead(IRPin) > DangerZone) // Stops and looks for new direction if object is detected
    {
      MReset();
      ScanDir();
    }
}


void ScanDir()  //IR is mounted on the servo backwards
{
  DirServo.write(0);  // Turn Servo Right
  delay(325);         // Time it takes @ 0.21/60degress + a little extra (90 degress = 1.5 x 210mS)
  long Rdist = ReadAnalogAVG(IRPin, 5);     //Get Average of 5 Readings

  DirServo.write(179);  // Turn Servo Left
  delay(650);           // 180 degress = 3 x 210ms
  long Ldist = ReadAnalogAVG(IRPin, 5);    //Get Average of 5 Readings

  DirServo.write(90);   // Turn Servo Straight
  if (Ldist > Rdist)    // Decide if there is more room to the left or right
  {
    Left90();   // Turn Robot Left
  }
  else
  {
    Right90();  // Turn Robot Right
  }
  MForward();   // Move Forward
}


long ReadAnalogAVG(int Port, int Samples)  // Calculates the Average of a sensors readings
{
  long Accumulator = 0;
  for (int i = 0; i < Samples; i ++)
  {
    Accumulator = Accumulator + analogRead(Port);   // Add up Readings from IR
    delay(55);   // Sharp IR takes approx 51ms to refresh
  }
  return (Accumulator / Samples);    // Get Average
}

